@@ -7,7 +7,7 @@ use Carp;
 use File::Spec;
 use vars qw($VERSION);
 
-$VERSION = '0.13';
+$VERSION = '0.14';
 
 sub new_from_file {
     my ( $proto, $filename ) = @_;
@@ -81,9 +81,23 @@ sub version {
 
 __END__
 
+=pod
+
+=begin markdown
+
+[![CPAN version](https://badge.fury.io/pl/Module-Info-File.svg)](http://badge.fury.io/pl/Module-Info-File)
+[![Build Status](https://travis-ci.org/jonasbn/Module-Info-File.svg?branch=master)](https://travis-ci.org/jonasbn/Module-Info-File)
+[![Coverage Status](https://coveralls.io/repos/jonasbn/Module-Info-File/badge.png)](https://coveralls.io/r/jonasbn/Module-Info-File)
+
+=end markdown
+
 =head1 NAME
 
-Module::Info::File - retrieves module information from a file or script
+Module::Info::File - retrieve module information from a file
+
+=head1 VERSION
+
+This POD describes version 0.13 of Module::Info::File
 
 =head1 SYNOPSIS
 
@@ -99,10 +113,6 @@ Module::Info::File - retrieves module information from a file or script
 
 	$mod->inc_dir();
 
-=head1 VERSION
-
-This POD describes version 0.13 of Module::Info::File
-
 =head1 DESCRIPTION
 
 Module::Info (SEE REFERENCES), are lacking functionality of being able
